@@ -400,11 +400,15 @@ LOGGING = {
             'filename': '/var/log/hyperkitty/hyperkitty.log',
             'formatter': 'verbose',
         },
+        'console': {
+            'class': 'logging.StreamHandler',
+            'formatter': 'simple',
+        },
     },
     'loggers': {
         'django.request': {
-            'handlers': ['mail_admins', 'file'],
-            'level': 'ERROR',
+            'handlers': ['mail_admins', 'file', 'console'],
+            'level': 'INFO',
             'propagate': True,
         },
         'django': {
@@ -413,8 +417,8 @@ LOGGING = {
             'propagate': True,
         },
         'hyperkitty': {
-            'handlers': ['file'],
-            'level': 'DEBUG',
+            'handlers': ['file', 'console'],
+            'level': 'INFO',
             'propagate': True,
         },
     },
@@ -484,6 +488,9 @@ HYPERKITTY_ALLOW_WEB_POSTING = True
 
 HYPERKITTY_ENABLE_GRAVATAR = True
 
+# Number of items in the mailing lists feeds
+HYPERKITTY_MLIST_FEED_LENGTH = 30
+
 try:
     from settings_local import *
 except ImportError:
